@@ -9,4 +9,4 @@ __docformat__ = "restructuredtext en"
 
 from cubicweb.web.views import facets
 
-facets.FilterBox.bk_linkbox_template = u'<div class="facet-action">%s</div>'
+facets.FilterBox.bk_linkbox_template = '<div class="facet-action">%s</div>'
