@@ -15,34 +15,38 @@ from cubicweb.web.component import Separator
 
 @monkeypatch(Separator)
 def render(self, w):
-    w(u'<li class="divider"></li>')
+    w('<li class="divider"></li>')
 
 
 def bwcompatible_render_item(w, item):
-    if hasattr(item, 'render'):
-        if getattr(item, 'newstyle', False):
+    if hasattr(item, "render"):
+        if getattr(item, "newstyle", False):
             if isinstance(item, Separator):
                 item.render(w)
             else:
-                w(u'<li>')
+                w("<li>")
                 item.render(w)
-                w(u'</li>')
+                w("</li>")
         else:
             item.render(w)  # XXX displays <li> by itself
     else:
-        w(u'<li>%s</li>' % item)
+        w("<li>%s</li>" % item)
 
 
 @monkeypatch(htmlwidgets.BoxMenu)
 def _render(self):
-    tag = u'li' if self.isitem else u'div'
-    self.w(u'<%s class="dropdown">' % tag)
-    self.w(u'<a class="dropdown-toggle" data-toggle="dropdown" href="#">'
-           u'%s&nbsp;'
-           u'<span class="caret"></span>'
-           u'</a>' % self.label)
-    self.w(u'<ul class="dropdown-menu">')
+    tag = "li" if self.isitem else "div"
+    self.w('<%s class="dropdown">', tag)
+    self.w(
+        '<a class="dropdown-toggle" data-toggle="dropdown" href="#">'
+        "%s&nbsp;"
+        '<span class="caret"></span>'
+        "</a>",
+        self.label,
+        escape=False,
+    )
+    self.w('<ul class="dropdown-menu">')
     for item in self.items:
         bwcompatible_render_item(self.w, item)
-    self.w(u'</ul>')
-    self.w(u'</%s>' % tag)
+    self.w("</ul>")
+    self.w("</%s>", tag)
